==> seedsui-react-5.5.1.tgz: package/es/ReactRender.js <==
import _regeneratorRuntime from "@babel/runtime/regenerator";

function asyncGeneratorStep(gen, resolve, reject, _next, _throw, key, arg) { try { var info = gen[key](arg); var value = info.value; } catch (error) { reject(error); return; } if (info.done) { resolve(value); } else { Promise.resolve(value).then(_next, _throw); } }

function _asyncToGenerator(fn) { return function () { var self = this, args = arguments; return new Promise(function (resolve, reject) { var gen = fn.apply(self, args); function _next(value) { asyncGeneratorStep(gen, resolve, reject, _next, _throw, "next", value); } function _throw(err) { asyncGeneratorStep(gen, resolve, reject, _next, _throw, "throw", err); } _next(undefined); }); }; }

// React17
import ReactDOM from 'react-dom'; // React18

var createRoot = null;

try {
  var _ReactDomClient, _ReactDomClient2;

  var ReactDomClient = require('react-dom/client');

  if ((_ReactDomClient = ReactDomClient) === null || _ReactDomClient === void 0 ? void 0 : _ReactDomClient["default"]) ReactDomClient = ReactDomClient["default"];
  createRoot = ((_ReactDomClient2 = ReactDomClient) === null || _ReactDomClient2 === void 0 ? void 0 : _ReactDomClient2.createRoot) || null;
} catch (error) {
  createRoot = null;
} // 装载(React 18)


var MARK = '__SeedsUI_root__';

function modernRender(node, container) {
  var root = container[MARK] || createRoot(container);
  root.render(node); // 记录root对象到dom上, 防止重复createRoot

  container[MARK] = root;
} // 装载(React 17)


function legacyRender(node, container) {
  ReactDOM.render(node, container);
} // 装载


export function render(node, container) {
  if (createRoot) {
    modernRender(node, container);
    return;
  }

  legacyRender(node, container);
} // 卸载(React 18)

function modernUnmount(_x) {
  return _modernUnmount.apply(this, arguments);
} // 卸载(React 17)


function _modernUnmount() {
  _modernUnmount = _asyncToGenerator( /*#__PURE__*/_regeneratorRuntime.mark(function _callee(container) {
    return _regeneratorRuntime.wrap(function _callee$(_context) {
      while (1) {
        switch (_context.prev = _context.next) {
          case 0:
            return _context.abrupt("return", Promise.resolve().then(function () {
              var _container$MARK;

              (_container$MARK = container[MARK]) === null || _container$MARK === void 0 ? void 0 : _container$MARK.unmount();
              delete container[MARK];
            }));

          case 1:
          case "end":
            return _context.stop();
        }
      }
    }, _callee);
  }));
  return _modernUnmount.apply(this, arguments);
}

function legacyUnmount(container) {
  ReactDOM.unmountComponentAtNode(container);
}

export function unmount(_x2) {
  return _unmount.apply(this, arguments);
} // 默认导出

function _unmount() {
  _unmount = _asyncToGenerator( /*#__PURE__*/_regeneratorRuntime.mark(function _callee2(container) {
    return _regeneratorRuntime.wrap(function _callee2$(_context2) {
      while (1) {
        switch (_context2.prev = _context2.next) {
          case 0:
            if (!createRoot) {
              _context2.next = 2;
              break;
            }

            return _context2.abrupt("return", modernUnmount(container));

          case 2:
            legacyUnmount(container);

          case 3:
          case "end":
            return _context2.stop();
        }
      }
    }, _callee2);
  }));
  return _unmount.apply(this, arguments);
}

export default {
  render: render,
  unmount: unmount
};

==> seedsui-react-5.5.8.tgz: package/es/ReactRender.js <==
import _regeneratorRuntime from "@babel/runtime/regenerator";

function asyncGeneratorStep(gen, resolve, reject, _next, _throw, key, arg) { try { var info = gen[key](arg); var value = info.value; } catch (error) { reject(error); return; } if (info.done) { resolve(value); } else { Promise.resolve(value).then(_next, _throw); } }

function _asyncToGenerator(fn) { return function () { var self = this, args = arguments; return new Promise(function (resolve, reject) { var gen = fn.apply(self, args); function _next(value) { asyncGeneratorStep(gen, resolve, reject, _next, _throw, "next", value); } function _throw(err) { asyncGeneratorStep(gen, resolve, reject, _next, _throw, "throw", err); } _next(undefined); }); }; }

// React17
import ReactDOM from 'react-dom'; // React18

var createRoot = null;

try {
  var _ReactDomClient, _ReactDomClient2;

  var ReactDomClient = require('react-dom/client');

  if ((_ReactDomClient = ReactDomClient) === null || _ReactDomClient === void 0 ? void 0 : _ReactDomClient.default) ReactDomClient = ReactDomClient.default;
  createRoot = ((_ReactDomClient2 = ReactDomClient) === null || _ReactDomClient2 === void 0 ? void 0 : _ReactDomClient2.createRoot) || null;
} catch (error) {
  createRoot = null;
} // 装载(React 18)


var MARK = '__SeedsUI_root__';

function modernRender(node, container) {
  var root = container[MARK] || createRoot(container);
  root.render(node); // 记录root对象到dom上, 防止重复createRoot

  container[MARK] = root;
} // 装载(React 17)


function legacyRender(node, container) {
  ReactDOM.render(node, container);
} // 装载


export function render(node, container) {
  if (createRoot) {
    modernRender(node, container);
    return;
  }

  legacyRender(node, container);
} // 卸载(React 18)

function modernUnmount(_x) {
  return _modernUnmount.apply(this, arguments);
} // 卸载(React 17)


function _modernUnmount() {
  _modernUnmount = _asyncToGenerator( /*#__PURE__*/_regeneratorRuntime.mark(function _callee(container) {
    return _regeneratorRuntime.wrap(function _callee$(_context) {
      while (1) {
        switch (_context.prev = _context.next) {
          case 0:
            return _context.abrupt("return", Promise.resolve().then(function () {
              var _container$MARK;

              (_container$MARK = container[MARK]) === null || _container$MARK === void 0 ? void 0 : _container$MARK.unmount();
              delete container[MARK];
            }));

          case 1:
          case "end":
            return _context.stop();
        }
      }
    }, _callee);
  }));
  return _modernUnmount.apply(this, arguments);
}

function legacyUnmount(container) {
  ReactDOM.unmountComponentAtNode(container);
}

export function unmount(_x2) {
  return _unmount.apply(this, arguments);
} // 默认导出

function _unmount() {
  _unmount = _asyncToGenerator( /*#__PURE__*/_regeneratorRuntime.mark(function _callee2(container) {
    return _regeneratorRuntime.wrap(function _callee2$(_context2) {
      while (1) {
        switch (_context2.prev = _context2.next) {
          case 0:
            if (!createRoot) {
              _context2.next = 2;
              break;
            }

            return _context2.abrupt("return", modernUnmount(container));

          case 2:
            legacyUnmount(container);

          case 3:
          case "end":
            return _context2.stop();
        }
      }
    }, _callee2);
  }));
  return _unmount.apply(this, arguments);
}

export default {
  render: render,
  unmount: unmount
};
